pub(crate) struct ChannelTelemetry {
pub(crate) phase_raw: i64,
pub(crate) phase: ScaledStatistics,
pub(crate) power: ScaledStatistics,
pub(crate) aux_adc: f32,
pub(crate) mod_amp: f32,
pub(crate) holds: Wrapping<u32>,
pub(crate) slips: Wrapping<u32>,
pub(crate) blanks: Wrapping<u32>,
pub(crate) rf_power: f32,
}Expand description
Channel Telemetry, all undersampled and not AA filtered
Fields
phase_raw: i64Current phase.
phase: ScaledStatisticsDemodulated phase statistics in turns
power: ScaledStatisticsDemodulated power (amplitude squared) statistics re full scale
aux_adc: f32Auxiliary front panel ADC input values, V
mod_amp: f32Modulation amplitude re full scale
holds: Wrapping<u32>Number of cycles where digital input held amplitude and cleared the frequency servo.
slips: Wrapping<u32>Number of potential phase slips where the absolute phase difference between successive samples is larger than π/2.
blanks: Wrapping<u32>Counter for the number of samples with low power where the frequency servo was cleared.
rf_power: f32Total RF power in dBm as reported by the RF detector.