pub struct Fls {
pub(crate) ext_clk: bool,
pub(crate) channel: [Channel; 2],
pub(crate) pll_bandwidth: f32,
pub(crate) pll_split: f32,
pub(crate) telemetry_period: f32,
pub(crate) stream: Target,
pub(crate) activate: bool,
}Expand description
Settings structure for the application. All fields in this structure are available through MQTT and can be configured at runtime.
Fields
ext_clk: boolExternal 100 MHz reference
channel: [Channel; 2]Channel-specific settings.
pll_bandwidth: f32Lockin demodulation oscillator PLL crossover in Hz. This PLL reconstructs the DDS SYNC clock output on the CPU clock timescale.
pll_split: f32PLL lead-lag pole-zero ratio
telemetry_period: f32Telemetry output period in seconds.
stream: TargetSpecifies the target for data streaming.
activate: boolActivate settings
If true each settings change immediately results in activation.
If false, activation is suppressed.
Use this to synchronize changes.
Implementations